# pytest-litf


A pytest plugin that stream output in JSON compatible with [Language Independent Test Format](https://github.com/Lothiraldan/litf).

It can be used with [Balto: BAlto is a Language independent Test Orchestrator](https://lothiraldan.github.io/balto/).

--------------

This [Pytest](https://github.com/pytest-dev/pytest) plugin was
generated with
[Cookiecutter](https://github.com/audreyr/cookiecutter) along with
[hackebrot](https://github.com/hackebrot)'s
[Cookiecutter-pytest-plugin](https://github.com/pytest-dev/cookiecutter-pytest-plugin) template.

# Features


-  TODO

# Requirements


-  TODO

# Installation


You can install "pytest-litf" via
[pip](https://pypi.python.org/pypi/pip/) from
[PyPI](https://pypi.python.org/pypi):

```
    $ pip install pytest-litf
```

# Usage


-  TODO

# Contributing


Contributions are very welcome.

# License

Distributed under the terms of the
[MIT](http://opensource.org/licenses/MIT) license, "pytest-litf" is
free and open source software

# Issues

If you encounter any problems, please [file an
issue](https://github.com/lothiraldan/pytest-litf/issues) along with
a detailed description.
